====================
wagtail-stacks-embed
====================

A Stacks application for handling embeddable media (like COVE Videos, YouTube Videos or Soundcloud sounds...basically anything that uses an embed code!).

Release Notes
-------------

TBD
